package Davis::WeatherLog;

use DBI;
use Date::Manip;

use strict;

use Davis::DataPoint;
use Davis::Derived;

use Exporter;
use vars qw( @ISA @EXPORT @EXPORT_OK );
@ISA = qw( Exporter );
@EXPORT = qw(
	barometer_range
	barometer_history
	);

sub barometer_range
{
   my $hours = shift || 3;

   my $dbh = DBI->connect('dbi:Oracle:MISC', 'weather', 'ycgsfn');
   $dbh->do("alter session set nls_date_format = 'yyyymmdd'");

   my ($high, $low) = $dbh->selectrow_array("
	select max(barometer), min(barometer)
	from weather_log
	where timestamp >= (sysdate - :1 / 24)
	", undef, $hours);

   return ($high, $low);
}

sub barometer_history
{
   my $hours = shift || 3;

   my $dbh = DBI->connect('dbi:Oracle:MISC', 'weather', 'ycgsfn');
   $dbh->do("alter session set nls_date_format = 'yyyymmdd'");

   my ($date, $oldval) = $dbh->selectrow_array("
	select timestamp, barometer
	from weather_log
	order by abs(timestamp - (sysdate - :1 / 24))
	", undef, $hours);

   return $oldval;
}

sub new
{
   my $package = shift;

   my $dbh = DBI->connect('dbi:Oracle:misc', 'weather', 'ycgsfn');

   die DBI->errstr unless $dbh;

   $dbh->do("alter session set nls_date_format = 'yyyymmddhh24mi'");

   my $self = bless {
	dbh => $dbh,
	}, $package;
}

sub get_datapoint
{
   my $self = shift;
   my $timestamp = shift;

   $timestamp = UnixDate(ParseDate($timestamp), "%Y%m%d%H%M");

   warn "Using timestamp $timestamp";

   my $cursor = $self->{dbh}->prepare("
	select *
	from weather_log
	where timestamp = (
		select max(timestamp)
		from weather_log
		where abs(timestamp - to_date(:1)) = (
			select min(abs(timestamp - to_date(:1)))
			from weather_log
			)
		)
	");
   $cursor->execute($timestamp);
   my $hash = $cursor->fetchrow_hashref;
   $cursor->finish;

   $hash->{DEW_POINT} = dew_point($hash->{OUTSIDE_TEMP}, $hash->{OUTSIDE_HUM});

   return new Davis::DataPoint( %$hash );
}

sub get_max
{
   my $self = shift;
   my $days = shift;

   warn "Getting MAX $days";

   my ($temp, $hum, $dew, $thi) = $self->{dbh}->selectrow_array("
	select
		max(outside_temp),
		max(outside_hum),
		max(d_dewpoint),
		max(d_thi)
	from weather_log
	where timestamp >= trunc(sysdate) - :1 + 1
	", undef, $days);

   return new Davis::DataPoint(
	OUTSIDE_TEMP => $temp,
	OUTSIDE_HUM => $hum,
	D_DEWPOINT => $dew,
	D_THI => $thi,
	);
}

sub get_min
{
   my $self = shift;
   my $days = shift;

   warn "Getting MIN $days";

   my ($temp, $hum, $dew) = $self->{dbh}->selectrow_array("
	select
		min(outside_temp),
		min(outside_hum),
		min(d_dewpoint)
	from weather_log
	where timestamp >= trunc(sysdate) - :1 + 1
	", undef, $days);

   return new Davis::DataPoint(
	OUTSIDE_TEMP => $temp,
	OUTSIDE_HUM => $hum,
	D_DEWPOINT => $dew,
	);
}




1;

