#!/usr/local/bin/perl

use DBI;

use strict;

use Davis::Derived;
use Davis::WeatherMonitorII;

$|=1;

$ENV{ORACLE_HOME} = '/home/oracle/app/oracle/product/8.0.5';

my $dbh = DBI->connect('dbi:Oracle:MISC', 'weather', 'ycgsfn', {AutoCommit => 1, PrintError => 0}) || die DBI::errstr;

my $wm = new Davis::WeatherMonitorII;

my $oldest = $wm->get_oldest_archive_index;
my $next = $wm->get_next_archive_index;

my $last = ($next - 1) % $wm->archive_array_size;

my $dups = 10;
for (my $i = $last; $dups && $i != $oldest; $i = ($i - 1) % $wm->archive_array_size)
{
   my $data;

   do {
      $data = $wm->get_archive_entry($i);
   } until ($data && $data->{date} > 0);

   my $dew = dew_point($data->outside_temp, $data->outside_hum);
   my $thi = temp_hum_index($data->outside_temp, $data->outside_hum);

   $thi = undef if ($thi eq 'LO' || $thi eq 'HI');

   my $year = 2001;
   $year = 2000 if $data->date > '0701';

   printf "%s: %04s%04s:%04s,%s -- ",
	$i,
	$year,
	$data->date,
	$data->time,
	join(",",
		$data->barometer,
		$data->inside_temp,
		$data->inside_hum,
		$data->outside_temp,
		$data->outside_hum,
		$data->wind_speed,
		$data->wind_dir,
		$data->interval_rain,
		$data->wind_gust,
		$dew,
		$thi,
		),
	;

   $dbh->do("
	insert into weather_log (
		timestamp,
		barometer,
		inside_temp,
		inside_hum,
		outside_temp,
		outside_hum,
		wind_speed,
		wind_dir,
		rain_int,
		wind_gust,
		d_dewpoint,
		d_thi
		)
	values (to_date(:1, 'yyyymmddhh24mi'), :2, :3, :4, :5, :6, :7, :8, :9, :10, :11, :12)
	",
		undef,
		sprintf("%04s%04s%04s", $year, $data->date, $data->time),
		$data->barometer,
		$data->inside_temp,
		$data->inside_hum,
		$data->outside_temp,
		$data->outside_hum,
		$data->wind_speed,
		$data->wind_dir,
		$data->interval_rain,
		$data->wind_gust,
		$dew,
		$thi,
	);

   if ($dbh->err == 1)
   {
      print "already there.\n";
      $dups--;
   }
   elsif ($dbh->err)
   {
      print $dbh->errstr, "\n";
      die;
   }
   else
   {
      print "done.\n";
   }

   # last;
}

# $dbh->do("update weather_log set d_thi = null where d_thi = 0");

#$dbh->do("
#	update weather_log a
#	set interval = timestamp - ( select max(timestamp) from weather_log b where b.timestamp < a.timestamp )
#	where interval is null
#");

exit;



