#!/usr/local/bin/perl

use Chart::GnuPlot;
use DBI;
use Data::Dumper;
use Date::Manip;
use Davis::Derived;

use strict;

$ENV{ORACLE_HOME} = '/home/oracle/app/oracle/product/8.0.5';

my $dbh = DBI->connect('dbi:Oracle:MISC', 'weather', 'ycgsfn');

my $data = $dbh->selectall_arrayref("
	select
		to_char(timestamp, 'mm/dd/yyyy-hh24:mi'),
		inside_temp,
		outside_temp,
		inside_hum,
		outside_hum,
		barometer
	from weather_log
	where outside_temp is not null and outside_hum is not null
		-- and timestamp >= trunc(sysdate - 3)
	order by timestamp
	");

my $gp = Chart::GnuPlot->new();

my $params = {
		# title => 'Last 3 Days',
		terminal => 'gif',
		size => '640,300',
		timefmt => '%m/%d/%Y-%H:%M',
		data => [ $data ],
		grid => 1,
		key => 'bottom right',
		# plots => [ ],
		colours => { series => ['0000ff', 'ff0000', 'ff8000', '00ff40'], },
	};


my ($image, $ext);

$params->{title} = 'Barometer';
$params->{plots} = [ { columns => [1, 6], type => 'lines', title => 'Barometer' } ];
($image, $ext) = $gp->plot($params);
&writeout("barometer.$ext", $image);

# $params->{title} = 'Inside Temp';
# $params->{plots} = [ { columns => [1, 2], type => 'lines', title => 'Inside Temp' } ];
# ($image, $ext) = $gp->plot($params);
# &writeout("insidetemp.$ext", $image);

$params->{title} = 'Outside Temp';
$params->{plots} = [ { columns => [1, 3], type => 'lines', title => 'Outside Temp' } ];
($image, $ext) = $gp->plot($params);
&writeout("outsidetemp.$ext", $image);

# $params->{title} = 'Inside Humidity';
# $params->{plots} = [ { columns => [1, 4], type => 'lines', title => 'Inside Hum' } ];
# ($image, $ext) = $gp->plot($params);
# &writeout("insidehum.$ext", $image);

$params->{yrange} = [0, 100];

$params->{title} = 'Outside Humidity';
$params->{plots} = [ { columns => [1, 5], type => 'lines', title => 'Outside Hum' } ];
($image, $ext) = $gp->plot($params);
&writeout("outsidehum.$ext", $image);


exit;


sub writeout
{
   my $filename = shift;
   my $data = shift;

   open (OUT, ">$filename");
   binmode OUT;
   print OUT $data;
   close OUT;
}


