#!/usr/local/bin/perl

use Data::Dumper;

use strict;

use Davis::Derived;
use Davis::WeatherMonitorII;
use Davis::WeatherLog;

my $wm = new Davis::WeatherMonitorII(
	rev => 'E',
	);

die "Didn't connect to console." unless $wm;

my ($high, $low) = &barometer_range;
my $old = &barometer_history;

my $data = $wm->loop;

printf qq{ 
Inside: %.1f F, %s%% Rel Hum

Outside: %.1f F, %s%% Rel Hum, Dew Point %.1f F, THI %.1f F

Wind: %s at %s mph (%s)

Barometer: %.3f" (%.1f mb)
   3 Hour Change: %.3f" (%.1f mb)

Rain: %.2f"

Forecast:
%s

},
	$data->inside_temp,
	$data->inside_hum,
	$data->outside_temp,
	$data->outside_hum,
	dew_point($data->outside_temp, $data->outside_hum),
	temp_hum_index($data->outside_temp, $data->outside_hum),
	&compass_point($data->wind_dir),
	$data->wind_speed,
	&windspeed_description($data->wind_speed),
	$data->barometer, mbars($data->barometer),
	$data->barometer - $old, mbars($data->barometer) - mbars($old),
	$data->rain,
	join("\nOR\n", &get_forecast($data->wind_dir, mbars($data->barometer), mbars($data->barometer) - mbars($old))),


#	&forecast(
#		mbars => mbars($data->barometer),
#		old_mbars => mbars($old),
#		winddir => $data->wind_dir,
#		),

	;

exit;


sub get_forecast
{
   my $wind_dir = shift;
   my $bar = shift;
   my $delta_bar = shift;

   my $dbh = DBI->connect('dbi:Oracle:MISC', 'weather', 'ycgsfn');

   my $answers = $dbh->selectcol_arrayref("
	select forecast
	from forecast_rules
	where
        	(
                	( wind_min < wind_max and :1 between wind_min and wind_max )
                	or ( wind_min > wind_max and ( wind_min <= :1 or :1 <= wind_max ) )
        	)
        	and (
                	( bar_min is not null and bar_max is not null and :2 between bar_min and bar_max )
                	or ( bar_min is null and :2 <= bar_max )
                	or ( bar_max is null and bar_min <= :2 )
        	)
        	and (
                	( delta_bar_min is not null and delta_bar_max is not null and :3 between delta_bar_min and delta_bar_max )
                	-- or ( delta_bar_min is null and delta_bar_max is null )
                	or ( delta_bar_min is null and :3 <= delta_bar_max )
                	or ( delta_bar_max is null and delta_bar_min <= :3 )
        	)
	", undef, $wind_dir, $bar, $delta_bar);


   return @$answers;
}


