#!/usr/local/bin/perl

use Curses;
use POSIX qw(strftime);

use strict;

use Davis::Derived;
use Davis::VantagePro;

my $van = new Davis::VantagePro;

my @format_info = (
	[2, 20, 10, "%.1f F"],
	[7, 20, 10, "%.1f F"],
	[12, 20, 10, "%s mph"],
	[13, 20, 10, "%s deg"],
	[15, 20, 10, "%.3f\""],
	[3, 20, 10, "%s%%"],
	[8, 20, 10, "%s%%"],
	[16, 20, 10, "%.2f\""],
	[4, 20, 10, "%.1f F"],
	[9, 20, 10, "%.1f F"],
	);

initscr;

my @lastdata;

addstr(1, 0, "Inside");
addstr(2, 5, "Temperature:");
addstr(3, 5, "Humidity:");
addstr(4, 5, "Dew Point:");
addstr(6, 0, "Outside");
addstr(7, 5, "Temperature:");
addstr(8, 5, "Humidity:");
addstr(9, 5, "Dew Point:");
addstr(11, 0, "Wind");
addstr(12, 5, "Speed:");
addstr(13, 5, "Direction:");
addstr(15, 0, "Barometer:");
addstr(16, 0, "Rain:");

while (1)
{

   my @data = &get_data;

   addstr(18, 0, ' ' x 30);
   addstr(18, 0, strftime("%c", localtime));

   foreach (0..9)
   {
      if ($data[$_] != $lastdata[$_] || ! defined $lastdata[$_])
      {
         addstr($format_info[$_]->[0], $format_info[$_]->[1],
		' ' x $format_info[$_]->[2]);
         addstr($format_info[$_]->[0], $format_info[$_]->[1],
		sprintf($format_info[$_]->[3], $data[$_]));
      }

      if (@lastdata)
      {
         if ($data[$_] > $lastdata[$_])
         {
            addstr($format_info[$_]->[0], $format_info[$_]->[1]+10, '^');
         }
         elsif ($data[$_] < $lastdata[$_])
         {
            addstr($format_info[$_]->[0], $format_info[$_]->[1]+10, 'v');
         }
      }
   }

   refresh;
   @lastdata = @data;
   sleep 30;
}

endwin;

exit;


sub get_data
{

   my $data = $van->loop;

   return (
	$data->{inside_temp}, $data->{outside_temp},
	$data->{wind_speed}, $data->{wind_dir},
	$data->{barometer},
	$data->{inside_hum}, $data->{outside_hum},
	$data->{rain},
	dew_point($data->{inside_temp}, $data->{inside_hum}),
	dew_point($data->{outside_temp}, $data->{outside_hum}),
	);
}


