#!/usr/local/bin/perl

use CGI;
use Chart::Graph::Gnuplot qw(&gnuplot);
use Image::Magick;
use DBI;
use Data::Dumper;
use Misc;

use strict;

use Davis::Derived;

REQUEST:
foreach my $q (new CGI)
{

   if ($ENV{REQUEST_METHOD} eq 'HEAD')
   {
      # print STDERR "Just a HEAD request...\n";
      print $q->header;
      next REQUEST;
   }

   $ENV{DEBUG} = 0;
   $ENV{ORACLE_HOME} ||= '/home/oracle/app/oracle/product/8.0.5';

   my $days = $q->param('days') || 7;

   my $dbh = DBI->connect('dbi:Oracle:MISC', 'weather', 'ycgsfn');

   my $data = $dbh->selectall_hashref("
	select
		to_char(timestamp, 'yyyymmdd hh24:mi') ts,
		timestamp - trunc(sysdate-3) xindex,
		inside_temp,
		outside_temp,
		d_dewpoint
	from weather_log
	where timestamp >= trunc(sysdate - 3)
	order by timestamp
	", 'TS');
   die $dbh->errstr if $dbh->err;

   # print Dumper($data);

   my $global_options = {
	title => "Temp",
	size => '1,0.5',
	'output file' => 'temp.gif',
	'x-axis label' => 'Date',
	'y-axis label' => 'Temp (deg F)',
	xtics => [
		map { $_->[0] =~ s/ /\\n/; $_ }
		map { [$data->{$_}->{TS}, $data->{$_}->{XINDEX}] }
		grep { / (00|12):00$/ }
		sort keys %$data
		],
	};

   my $trace1 = [
	{
		title => 'Inside',
		type => 'matrix',
		style => 'lines',
	},
	[
		map { [$data->{$_}->{XINDEX}, $data->{$_}->{INSIDE_TEMP} ] } sort keys %$data
	]
	];

   my $trace2 = [
	{
		title => 'Outside',
		type => 'matrix',
		style => 'lines',
	},
	[
		map { [$data->{$_}->{XINDEX}, $data->{$_}->{OUTSIDE_TEMP} ] } sort keys %$data
	]
	];

   my $trace3 = [
	{
		title => 'Dew Point',
		type => 'matrix',
		style => 'lines',
	},
	[
		map { [$data->{$_}->{XINDEX}, $data->{$_}->{D_DEWPOINT} ] } sort keys %$data
	]
	];

   &gnuplot($global_options, $trace1, $trace2, $trace3);



}






